@@ -9,7 +9,7 @@ logger = logging.getLogger(__name__)
 # https://daskhub.dev.ctaodc.ch/services/downloadservice/fetch/pnfs/cta.cscs.ch/lst/DL1/20230226/v0.9_calib12100/tailcut84
 
 hubbase = "http://hub:5000"
-dsbase = urljoin(hubbase, "services/downloadservice/fetch/pnfs/cta.cscs.ch")
+dsbase = urljoin(hubbase, "services/downloadservice/fetch/pnfs/cta.cscs.ch/")
 
 
 def list_dir(url):
